<template>
  <el-popover placement="bottom" width="200" trigger="manual" v-model="visible" @show="showPopover">
    <el-select
      v-if="tableType === '企业性质' || tableType === '项目属性' ||tableType === '提交' || tableType === '审批' || tableType === '合同类型'"
      v-model="value"
      filterable
      placeholder="请选择"
      style='width: 100%;'
      @change='getSelect'>
      <el-option
        v-for="(optionItem, index) in optionsList"
        :key="index"
        :label="optionItem"
        :value="optionItem"/>
    </el-select>
    <el-cascader
      v-if="tableType === '行业细分'"
      ref="salesCas"
      :show-all-levels="false"
      placeholder="请选择行业细分"
      :options="optionsList"
      :props="{
        children: 'children',
        label: 'Name',
        value: 'Name'
      }"
      v-model="casVal"
      style="width: 100%;"
      @change='getCas'/>
      <el-select
        v-if="tableType === '商机类型'"
        v-model="busType"
        filterable
        placeholder="请选择"
        style='width: 100%;'
        @change='getSelect'>
        <el-option
          v-for="(optionItem, index) in optionsList"
          :key="index"
          :label="optionItem"
          :value="optionItem"/>
      </el-select>
    <!--<el-input
      placeholder="请输入内容"
      v-model="value"
      clearable
      @keyup.enter.native="confirm"
      ref="sInput"
    >
    </el-input>-->
    <div class='filterBtn'>
      <el-button size="mini" @click="resetData">取消</el-button>
      <el-button type="primary" size="mini" @click="confirm" style="margin-top:5px">确认</el-button>
    </div>
    <div slot="reference" style="margin-left:8px" @click.stop="popClick" v-clickoutside="closeOver" v-show="show">
      <img class="table-filter" src='../../../assets/img/tablefilter.png'/>
    </div>
  </el-popover>
</template>

<script>
import { GetIndustryListChildrenData } from '@/api/common'
import Lockr from 'lockr'
export default {
  name: 'CRMTableFilter',
  data () {
    return {
      value: '',
      casVal: '',
      busType: '',
      visible: false,
      iconColor: false,
      optionsList: []
    }
  },
  props: {
    show: {
      type: Boolean,
      default: false
    },
    tableType: {
      type: String,
      default: ''
    },
    type: {
      type: String,
      default: ''
    },
    defaultValue: {
      type: String,
      default: ''
    },
    options: {
      type: Array,
      default: function () {
        return []
      }
    },
    defaultProps: {
      type: Object,
      default: function () {
        return {
          label: 'label',
          value: 'value'
        }
      }
    }
  },
  watch: {
    defaultValue (newVal, oldVal) {
      const self = this
      self.value = newVal
    }

  },
  mounted () {
    this.getList()
    Lockr.set('comType', '')
    Lockr.set('casType', '')
  },
  methods: {
    showPopover () {
      this.$nextTick(() => {
        // this.$refs.sInput.focus()
      })
    },
    getSelect () {
      console.log(this.value)
      Lockr.set('comType', this.value)
    },
    getCas () {
      Lockr.set('casType', this.casVal[1])
    },
    getList () {
      if (this.tableType === '企业性质') {
        this.optionsList = ['国企', '外企', '民营', '其他']
      } else if (this.tableType === '行业细分') {
        this.getIndustryList()
      } else if (this.tableType === '项目属性') {
        this.optionsList = ['普通项目', 'LC协作', 'ACAD项目', 'ACAD重点客户', 'AEC项目', 'AEC倍增计划', 'MFG项目', 'MNE项目', '企业信息特例', '特别案例', '区域重点客户', '知识产权代理']
      } else if (this.tableType === '商机类型') {
        this.optionsList = ['Other', 'LC', 'ACAD', 'AEC', 'MFG', 'MNE']
      } else if (this.tableType === '提交') {
        this.optionsList = ['待提交', '已提交']
      } else if (this.tableType === '审批') {
        this.optionsList = ['审批中', '通过', '驳回']
      } else if (this.tableType === '合同类型') {
        this.optionsList = ['合同章', '公章']
      }
    },
    getIndustryList () {
      GetIndustryListChildrenData().then(res => {
        if (res.data.ErrorCode === 200) {
          let list = res.data.Result
          let array = this.addLabel(list)
          console.log(array)
          this.optionsList = array
        } else {
          return []
        }
      })
    },
    addLabel (arr) {
      for (let k in arr) {
        arr[k].Name = arr[k].CategoryName || '无类名'
        if (arr[k].IndustryData && arr[k].IndustryData.length < 1) {
          // 当后台返回的children为空时,页面会留空白，把空白部分去掉
          arr[k].children = undefined
        } else {
          arr[k].children = []
          for (let i in arr[k].IndustryData) {
            arr[k].children.push({Name: arr[k].IndustryData[i]})
          }
        }
      }
      return arr
    },
    resetData () {
      this.value = ''
      this.casVal = ''
      this.visible = false
      this.iconColor = false
      Lockr.set('comType', '')
      Lockr.set('casType', '')
      this.$emit('queryList')
    },
    closeOver () {
      this.visible = false
    },
    popClick (e) {
      // e.stopPropagation()
      this.visible = !this.visible
    },
    confirm () {
      this.visible = false
      this.iconColor = true
      if (this.value || this.casVal) {
        this.$emit('queryList', { value: this.value, busType: this.busType, casVal: this.casVal[1], tableType: this.tableType })
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.table-filter{
  width: 20px; /*no*/
  height: 20px; /*no*/
  margin-top: 1px;
}
.filterBtn{
  float: right;
  margin-top:12px;
  .el-button{
    width: 40px;
    height: 20px;
    font-size: 12px;
    line-height: 7px;
    padding: 2px;
  }
}
</style>
